# Технические особенности


## aiohttp

Запрос в API реализуются на основе клиентской части `aiohttp`, но если вы хотите использовать
`httpx` или другой асинхронный клиент – можете встроить в данную библиотеку свой модуль.

## msgspec

В качестве основы для моделирования объектов API используется библиотека `msgpec`, которая кратно
эффективнее всех существующих способов работы с моделями (даже популярный pydantic – хуже).
